
# DirectEpisodesMaker.py is part of The Ming Mods
# billy_bob_ming@yahoo.com

# Copyright (C) 2005, 2006  Richard Harris, Marco Rimoldi
# Released under the GNU General Public License
# (See the included COPYING file)

# The Ming Mods are free software; you can redistribute them and/or
# modify them under the terms of the GNU General Public License as published
# by the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# The Ming Mods are distributed in the hope that they will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with The Ming Mods; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from TheMingServer.makers.HTMLMaker import HTMLMaker
from TheMingServer.DirectEpisodes import PurchaseButton
from TheMingServer import lib
import os

# NOTE: This is simply a renamed EasyEpisodesMaker

class DirectEpisodesMaker(HTMLMaker):
	NAME = "DirectEpisodesMaker"
	INNER_PLATE = os.path.dirname(__file__) + os.sep + "plate"

	def __size(self, content):
		length = len(content)
		if length < 1000:
			content = content[:length/3]
		else:
			content = content[:200]
		if self.pre:
			content += ["\n</pre>\n"]
		return content

	def __preview_content(self, shebang, newbits):
		header = shebang[0+self.pre:5] + [""]
		if self.pre:
			header = ["<pre>\n"] + header + ["\n</pre>"]
		shebang = self.__size(shebang)
		newbits = header + self.__size(newbits)
		return shebang, newbits

	def __find(self, list, char):
		list = ["null"] + list
		for item in list:
			if char in item:
				return item.strip()
		return None

	def __parse_content(self, parsed_data):
		fee_line = self.__find(parsed_data["price"], ".")
		fee_line = lib.strip_html(fee_line)
		fee_w, fee_n = lib.tokens(fee_line, ":")
		author = parsed_data["shebang"][1 + self.pre].strip()
		author = lib.strip_html(author)
		return author, fee_w, fee_n

	def make(self, parsed_data):
		self.pre = parsed_data["shebang"][0].startswith("<pre>")
		author, fee_w, fee_n = self.__parse_content(parsed_data)
		parsed_data["shebang"], parsed_data["newbits"] = \
								self.__preview_content(parsed_data["shebang"], parsed_data["newbits"])
		p = PurchaseButton()
		email = self.__find(parsed_data["email"], "@")
		parsed_data["button_w"] = p.button(parsed_data["title"], author, email, fee_w, 1)
		parsed_data["button_n"] = p.button(parsed_data["title"], author, email, fee_n, 0)
		content = lib.get_lines(self.INNER_PLATE)
		parsed_data["content"] = lib.insert_tags(content, parsed_data)
		page = HTMLMaker.make(self, parsed_data)
		return page